@@ -9,6 +9,23 @@ from biblion.utils import can_tweet, load_path_attr
 from biblion.signals import post_published
 
 
+FIELDS = [
+    "section",
+    "author",
+    "markup",
+    "title",
+    "slug",
+    "teaser",
+    "content",
+    "description",
+    "primary_image",
+    "publish",
+]
+
+if can_tweet():
+    FIELDS.append("tweet")
+
+
 class AdminPostForm(forms.ModelForm):
 
     title = forms.CharField(
@@ -24,6 +41,9 @@ class AdminPostForm(forms.ModelForm):
     content = forms.CharField(
         widget=forms.Textarea(attrs={"style": "width: 80%; height: 300px;"})
     )
+    description = forms.CharField(
+        widget=forms.Textarea(attrs={"style": "width: 80%;"}),
+    )
     publish = forms.BooleanField(
         required=False,
         help_text="Checking this will publish this articles on the site",
@@ -37,6 +57,7 @@ class AdminPostForm(forms.ModelForm):
 
     class Meta:
         model = Post
+        fields = FIELDS
 
     def __init__(self, *args, **kwargs):
         super(AdminPostForm, self).__init__(*args, **kwargs)
